{% load i18n %}

{% block subject %}
{% blocktrans %}Login on {{ site_name }}{% endblocktrans %}
{% endblock subject %}

{% block text_body %}
{% blocktrans %}You're receiving this email because you requested a login code at {{ site_name }}.{% endblocktrans %}

{% blocktrans %}The code to login to {{ site_name }} is {{ short_token }}.{% endblocktrans %}

{% if url %}
  {% trans "Alternatively, click the following link to login." %}
  {{ url|safe }}
{% endif %}

{% trans "Thanks for using our site!" %}

{% blocktrans %}The {{ site_name }} team{% endblocktrans %}
{% endblock text_body %}

{% block html_body %}
<p>{% blocktrans %}You're receiving this email because you requested a login code at {{ site_name }}.{% endblocktrans %}</p>

<p>{% blocktrans %}The code to login to {{ site_name }} is: {{ short_token }}.{% endblocktrans %}</p>

{% if url %}
<p>
  {% trans "Alternatively, click the following link to login." %}
  <a href="{{ url|safe }}">Login</a>
</p>
{% endif %}

<p>{% trans "Thanks for using our site!" %}</p>

<p>{% blocktrans %}The {{ site_name }} team{% endblocktrans %}</p>
{% endblock html_body %}
