from django.utils.translation import gettext_lazy as _


class Messages:
    INVALID_CREDENTIALS_ERROR = _("Invalid credentials")
    TOKEN_SENT = _("A token has been sent to you")
    CANNOT_SEND_TOKEN = _("Unable to send token")
